==> v8.3.zip: ru_twords_ru_tw/bible/other/prison.md <==
# заключение, заключённый

## Определение:

Заключение — это принудительное ограничение или лишение свободы. Заключённый — это тот, кто находится в заключении.

* Заключённый может содержаться под стражей в ожидании суда и приговора.
* Синонимами этого слова являются: “арестованный”, “узник”, “невольник”, “пленник”, “заложник”.
* Божьих пророков и других Божьих людей часто заключали в тюрьму (устар. “темницу”), несмотря на то, что последние не совершали никаких преступлений.

## Варианты перевода:

* Синонимами существительного “заключение” являются слова “заточение” (устар.), “тюрьма”, “темница”.
* Подземелье — это подземная тюрьма. Обычно подземелье находилось в подвальной части дворцового комплекса. В этом же значении употребляется слово “темница”.
* Заключённым также может быть назван человек, попавший в плен к врагам и принудительно удерживаемый у них. В этом случае можно использовать такие синонимы этого слова: “пленник”, “заложник”.
* Слово “заключённый” можно перевести словосочетаниями “посаженный в тюрьму”, “находящийся в плену”, “находящийся в заточении”.

(См. также: [пленник](../other/captive.md))

## Ссылки на библейский текст:

* [Деян. 25:4-5](rc://*/tn/help/act/25/04)
* [Еф. 4:1-3](rc://*/tn/help/eph/04/01)
* [Лк. 12:57-59](rc://*/tn/help/luk/12/57)
* [Лк. 22:33-34](rc://*/tn/help/luk/22/33)
* [Мк. 6:16-17](rc://*/tn/help/mrk/06/16)
* [Мф. 5:25-26](rc://*/tn/help/mat/05/25)
* [Мф. 14:3-5](rc://*/tn/help/mat/14/03)
* [Мф. 25:34-36](rc://*/tn/help/mat/25/34)

## Данные о слове:

* Номера Стронга: H612, H613, H615, H616, H631, H1004, H1540, H3608, H3628, H3947, H4115, H4307, H4455, H4525, H4929, H5470, H6115, H6495, H7617, H7622, H7628, G1198, G1199, G1200, G1201, G1202, G1210, G2252, G3612, G4788, G4869, G5084, G5438, G5439

==> v9.2.zip: ru_twords_ru_tw/bible/other/prison.md <==
# заключение, заключённый

## Определение:

Заключение — это принудительное ограничение или лишение свободы. Заключённый — это тот, кто находится в заключении. 

* Заключённый может содержаться под стражей в ожидании суда и приговора. 
* Синонимами этого слова являются: “арестованный”, “узник”, “невольник”, “пленник”, “заложник”. 
* Божьих пророков и других Божьих людей часто заключали в тюрьму (устар. “темницу”), несмотря на то, что последние не совершали никаких преступлений. 

## Варианты перевода:

* Синонимами существительного “заключение” являются слова “заточение” (устар.), “тюрьма”, “темница”. 
* Подземелье — это подземная тюрьма. Обычно подземелье находилось в подвальной части дворцового комплекса. В этом же значении употребляется слово “темница”. 
* Заключённым также может быть назван человек, попавший в плен к врагам и принудительно удерживаемый у них. В этом случае можно использовать такие синонимы этого слова: “пленник”, “заложник”.
* Слово “заключённый” можно перевести словосочетаниями “посаженный в тюрьму”, “находящийся в плену”, “находящийся в заточении”.

(См. также: [пленник](../other/captive.md))

## Ссылки на библейский текст:

* [Деян. 25:4-5](rc://ru/tn/help/act/25/04)
* [Еф. 4:1-3](rc://ru/tn/help/eph/04/01)
* [Лк. 12:57-59](rc://ru/tn/help/luk/12/57)
* [Лк. 22:33-34](rc://ru/tn/help/luk/22/33)
* [Мк. 6:16-17](rc://ru/tn/help/mrk/06/16)
* [Мф. 5:25-26](rc://ru/tn/help/mat/05/25)
* [Мф. 14:3-5](rc://ru/tn/help/mat/14/03)
* [Мф. 25:34-36](rc://ru/tn/help/mat/25/34)

## Данные о слове:

* Номера Стронга: H612, H613, H615, H616, H631, H1004, H1540, H3608, H3628, H3947, H4115, H4307, H4455, H4525, H4929, H5470, H6115, H6495, H7617, H7622, H7628, G1198, G1199, G1200, G1201, G1202, G1210, G2252, G3612, G4788, G4869, G5084, G5438, G5439
